package com.ruoyi.frequency.mallrefund.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.frequency.mallrefund.entity.MallRefund;

import java.util.List;

/**
 * 订单退款Service接口
 *
 * @author liwenlong
 * @date 2024-01-25
 */
public interface MallRefundService extends IService<MallRefund>
{
    /**
     * 查询订单退款
     *
     * @param id 订单退款主键
     * @return 订单退款
     */
    public MallRefund selectMallRefundById(Long id);

    /**
     * 查询订单退款列表
     *
     * @param mallRefund 订单退款
     * @return 订单退款集合
     */
    public List<MallRefund> selectMallRefundList(MallRefund mallRefund);

    /**
     * 新增订单退款
     *
     * @param mallRefund 订单退款
     * @return 结果
     */
    public int insertMallRefund(MallRefund mallRefund);

    /**
     * 修改订单退款
     *
     * @param mallRefund 订单退款
     * @return 结果
     */
    public int updateMallRefund(MallRefund mallRefund);

    /**
     * 批量删除订单退款
     *
     * @param ids 需要删除的订单退款主键集合
     * @return 结果
     */
    public int deleteMallRefundByIds(Long[] ids,Integer delFlag);

}
